@@ -6,7 +6,7 @@
 options(continue="  ", width=60)
 options(SweaveHooks=list(fig=function() par(mar=c(4.1, 4.1, .3, 1.1))))
 pdf.options(pointsize=8) #text in graph about the same as regular text
-require(survival, quietly=TRUE)
+library(survival, quietly=TRUE)
 fdata <- flchain[flchain$futime > 7,]
 fdata$age2 <- cut(fdata$age, c(0,54, 59,64, 69,74,79, 89, 110),
                   labels = c(paste(c(50,55,60,65,70,75,80),
@@ -190,7 +190,7 @@ legend(730, .4, levels(fdata$group), lty=1, col=c(1,2,4),
 ### code chunk number 13: adjcurve.Rnw:553-562
 ###################################################
 id <- 1:nrow(fdata)
-cfit <- coxph(Surv(futime, death) ~ group + cluster(id), data=fdata, 
+cfit <- coxph(Surv(futime, death) ~ group, data=fdata, cluster=id,
               weight=rwt)
 summary(cfit)$robscore
 
@@ -263,9 +263,9 @@ wtscale <- table(fdata$group)/ tapply(fdata$rwt, fdata$group, sum)
 wt2 <- c(fdata$rwt * wtscale[fdata$group])
 c("rescaled cv"= sd(wt2)/mean(wt2), "rwt cv"=sd(fdata$rwt)/mean(fdata$rwt))
 
-cfit2a <- coxph(Surv(futime, death) ~ group + cluster(id),
+cfit2a <- coxph(Surv(futime, death) ~ group, cluster = id,
                 data=fdata, weight= rwt)
-cfit2b <- coxph(Surv(futime, death) ~ group + cluster(id),
+cfit2b <- coxph(Surv(futime, death) ~ group, cluster = id,
                 data=fdata, weight=wt2) 
 round(c(cfit2a$rscore, cfit2b$rscore),1)
 
@@ -292,7 +292,7 @@ for (i in 1:3) {
     for (j in 1:16) {
         stemp <- summary(temp[j], times=xtime, extend=T)
         smat[,i] <- smat[,i] + pi[j]*stemp$surv
-        serr[,i] <- serr[,i] + pi[i]*stemp$std.err^2
+        serr[,i] <- serr[,i] + pi[j]*stemp$std.err^2
         }
     }
 serr <- sqrt(serr)
